@@ -19,51 +19,89 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2008 PgPool Global Development Group
- * @version    CVS: $Id: ja.lang.php,v 1.15.2.1 2010/06/23 04:32:29 anzai Exp $
+ * @copyright  2003-2012 PgPool Global Development Group
+ * @version    CVS: $Id$
  */
 
 $message = array(
     'lang' => 'ja',
     'strLang' => '日本語',
+
+    'descArping_path' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンドのパス',
+    'descArping_cmd' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンド',
+    'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
+    'descBackend_flag' => 'フェイルオーバやデタッチの可否',
     'descBackend_hostname' => 'pgpoolが接続するPostgreSQLサーバ(postmaster)が動いているホスト名',
     'descBackend_port' => 'PostgreSQLサーバのポート番号',
     'descBackend_socket_dir' => 'PostgreSQLサーバのUnix domain socketのディレクトリ',
     'descBackend_weight' => 'ロードバランスモード時のSELECTを振り分ける「重み」の定義',
     'descBackend_data_directory' => 'PostgreSQLサーバのデータベースディレクトリ',
+    'descBlack_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
+    'descBlack_memqcache_table_list' => 'SELECT結果をキャッシュしたくないテーブル名のカンマ区切りのリスト',
+    'descCheck_temp_table' => '一時テーブルかどうかをチェック',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
     'descChild_max_connections' => '各pgpool子プロセスが終了するまでの接続回数',
-	'descClient_idle_limit' => 'クライアントからのクエリの最大待ち時間(秒)',
-	'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
+    'descClient_idle_limit' => 'クライアントからのクエリの最大待ち時間(秒)',
+    'descClient_idle_limit_in_recovery' => 'リカバリ中のクライアントからのクエリの最大待ち時間(秒)',
     'descConnection_cache' => 'コネクションキャッシュ機能の有無',
     'descConnection_life_time' => 'コネクションプール中のコネクションの有効期間(秒)',
-	'descEnable_pool_hba' => 'クライアント認証機能の有無',
+    'descDebug_level' => 'デバッグメッセージの詳細レベル（0は無効）',
+    'descDelay_threshold' => '許容するスタンバイサーバの遅延(バイト)',
+    'descDelegate_IP' => '仮想 IP アドレス',
+    'descEnable_pool_hba' => 'クライアント認証機能の有無',
     'descEnable_query_cache' => 'クエリキャッシュ機能の有無',
     'descFailover_command' => 'ノード切り離し時に起動するコマンド',
     'descFailback_command' => 'ノード復帰時に起動するコマンド',
+    'descFailover_if_affected_tuples_mismatch' => '更新行数が一致しないときにフェイルオーバ',
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
+    'descFollow_master_command' => 'マスタのフェイルオーバ後に実行するコマンド',
     'descHealth_check_period' => 'ヘルスチェックを行う間隔(秒)',
     'descHealth_check_timeout' => 'ヘルスチェックが長時間待たされるのを防ぐためのタイムアウト値(秒)',
     'descHealth_check_user' => 'ヘルスチェックを行うためのPostgreSQLユーザ名',
+    'descHealth_check_password' => 'ヘルスチェックを行うためのPostgreSQLパスワード',
+    'descHealth_check_max_retries' => 'ヘルスチェックに失敗した後にリトライする回数',
+    'descHealth_check_retry_delay' => 'ヘルスチェックのリトライの間の間隔（秒）',
+    'descIfconfig_path' => 'ifconfig コマンドのパス',
+    'descIf_down_cmd' => '仮想 IP を停止するために実行するコマンド',
+    'descIf_up_cmd' => '仮想 IP を起動するために実行するコマンド',
     'descIgnore_leading_white_space' => 'load balance時のSQL文行頭の空白を無視',
     'descInsert_lock' => 'INSERT時に自動的にトランザクションの開始，テーブルロック，トランザクションの終了',
     'descListen_addresses' => 'TCP/IPコネクションを受け付けるアドレス',
     'descLoad_balance_mode' => 'レプリケーションモード時にSELECT文を各ノードにロードバランス',
     'descLobj_lock_table' => 'ラージオブジェクトのレプリケーションでロック管理に使うためのテーブル名',
-	'descLog_connections' => '受信した接続のログを出力',
-	'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
+    'descLog_connections' => '受信した接続のログを出力',
+    'descLog_destination' => 'ログの出力先',
+    'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
+    'descLog_standby_delay' => 'スタンバイサーバの遅延をログに記録する',
     'descLog_statement' => 'SQL文をログ出力',
     'descLogdir' => 'pgpoolの各種ログファイルを格納するディレクトリ',
     'descLog_per_node_statement' => 'DBノード毎にSQL文をログ出力',
     'descPid_file_name' => 'pidファイルの名前',
     'descMaster_slave_mode' => 'マスタ/スレーブモードでpgpoolを運転',
+    'descMaster_slave_sub_mode' => 'マスタ/スレーブモードの伝播方法',
     'descMax_pool' => 'pgpoolの各サーバプロセスがキープするPostgreSQLへの最大コネクション数',
+    'descMemory_cache_enabled' => 'オンメモリクエリキャッシュの有効化',
+    'descMemqcache_method' => 'キャッシュストレージ',
+    'descMemqcache_memcached_host' => 'memcachedが動いているホスト名またはIPアドレス',
+    'descMemqcache_memcached_port' => 'memcachedのポート番号',
+    'descMemqcache_total_size' => 'キャッシュストレージに使用する共有メモリ領域のサイズ(バイト)',
+    'descMemqcache_max_num_cache' => 'キャッシュエントリの数',
+    'descMemqcache_expire' => 'クエリキャッシュの寿命(秒)。 0 は無限の寿命',
+    'descMemqcache_auto_cache_invalidation' => '更新されたテーブルに関連するキャッシュを無効化',
+    'descMemqcache_maxcache' => 'キャッシュされるSELECT実行結果の最大サイズ(バイト)',
+    'descMemqcache_cache_block_size' => 'キャッシュブロックサイズ(バイト)',
+    'descMemqcache_oiddir' => 'テーブルOIDを格納するディレクトリ',
+    'descNum_init_children' => 'Number of pgpool processes initially forked',
     'descNum_init_children' => 'preforkするpgpoolのサーバプロセス数',
+    'descOther_pgpool_hostname' => '監視する pgpool-II が稼働するホスト名',
+    'descOther_pgpool_port' => '監視する pgpool-II が稼働するポート番号',
+    'descOther_wd_port' => '監視する watchdog が稼働するポート番号',
     'descParallel_mode' => 'パラレルモードでpgpoolを運転',
     'descPcp_port' => 'pgpool-IIが受け付けているポート番号',
     'descPcp_socket_dir' => 'pcpがコネクションを受け付けるUnix domain socketディレクトリ',
     'descPcp_timeout' => 'この時間内にクライアントから応答がない場合はコネクションを切断して終了',
     'descPgpool2_hostname' => 'pgpool2 が動作しているホスト名',
+    'descPing_path' => 'ping コマンドのパス',
     'descPort' => 'pgpoolがコネクションを受け付けるポート番号',
     'descPrint_timestamp' => 'pgpoolのログにタイムスタンプを追加',
     'descRecovery_user' => 'リカバリを行うためのPostgreSQLユーザ',
@@ -71,43 +109,62 @@ $message = array(
     'descRecovery_1st_stage_command' => 'オンラインリカバリ第1ステージで実行するコマンド',
     'descRecovery_2nd_stage_command' => 'オンラインリカバリ第2ステージで実行するコマンド',
     'descRecovery_timeout' => 'オンラインリカバリ終了までの待ち時間(秒)。0 は待ち時間無し',
-	'descClient_idle_limit_in_recovery' => 'リカバリ中のクライアントからのクエリの最大待ち時間(秒)',
+    'descRelcache_expire' => 'システムカタログキャッシュの有効時間(秒)',
+    'descRelcache_size' => 'システムカタログキャッシュのサイズ(バイト)',
     'descReplication_mode' => 'レプリケーションモードの有効化',
     'descReplication_stop_on_mismatch' => 'マスタ/セカンダリ間のデータ不一致時に縮退運転',
-	'descReplicate_select' => 'SELECT 文のレプリケーション',
-    'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間',
+    'descReplicate_select' => 'SELECT 文のレプリケーション',
+    'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間。'.
+                                 '厳密でないレプリケーションモードでは、デッドロックが発生しやすくなります。',
     'descReset_query_list' => 'セッションが終了するときにコネクションを初期化するためのSQLコマンド',
+    'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
     'descSsl' => 'pgpool-IIとバックエンドの間のSSL接続',
     'descSsl_ca_cert' => 'opensslの-CAFileに指定するパス',
     'descSsl_ca_cert_dir' => 'opensslの-CApathに指定するディレクトリパス',
     'descSsl_cert' => 'フロントエンドとの接続に使用する公開x509証明書のフルパス',
     'descSsl_key' => 'フロントエンドとの接続に使用するプライベートキーファイルのフルパス',
-    'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
+    'descSr_check_period' => 'ストリーミングレプリケーションの遅延チェックの間隔(秒)',
+    'descSr_check_user' => 'ストリーミングレプリケーションの遅延チェックを行うユーザ',
+    'descSr_check_password' => 'ストリーミングレプリケーションの遅延チェックを行うユーザのパスワード',
+    'descSyslog_facility' => 'Syslogのファシリティ',
+    'descSyslog_ident' => 'Syslog中でのプログラム名',
     'descSystem_db_dbname' => 'System DBのデータベース名',
     'descSystem_db_hostname' => 'System DBが動いているホスト名',
     'descSystem_db_password' => 'System DBに接続するユーザのパスワード',
     'descSystem_db_port' => 'System DBに接続するためのポート番号',
     'descSystem_db_schema' => 'System DBのスキーマ',
     'descSystem_db_user' => 'System DBに接続するときのユーザ名',
+    'descTrusted_servers' => '上位サーバのコンマ区切りのリスト',
+    'descUse_watchdog' => 'watchdog 機能の有無',
+    'descWd_hostname' => 'watchdog プロセスが相互監視を受信するためのホスト名',
+    'descWd_interval' => '死活監視の間隔(秒)',
+    'descWd_life_point' => '死活監視のリトライ回数',
+    'descWd_lifecheck_query' => '死活監視で実行するクエリ',
+    'descWd_port' => 'watchdog プロセスが相互監視を受信するためのポート番号',
+    'descWhite_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
+    'descWhite_memqcache_table_list' => 'SELECT結果をキャッシュしたいテーブル名のカンマ区切りのリスト',
+
     'errAlreadyExist' => 'すでに登録されています',
     'errFileNotExecutable' => 'コマンドを実行できません',
     'errFileNotFound' => 'ファイルが見つかりません',
     'errFileNotWritable' => 'ファイルの書き込みができません',
     'errIllegalHostname' => '不正なホスト名です',
-	'errIllegalPipe' => 'パイプの指定が不正です',
+    'errIllegalPipe' => 'パイプの指定が不正です',
     'errInputEverything' => 'すべてを入力してください',
     'errNoDefined' => 'パラメータが設定されていません',
-    'errNotSameLength' => '列名リストと列データ型リストの配列の長さが一致しません。同じ要素数である必要があります。',
+    'errNotSameLength' => '列名リストと列データ型リストの配列の長さが一致しません。'.
+                          '同じ要素数である必要があります。',
     'errPasswordMismatch' => 'パスワードが一致しません',
     'errRequired' => 'これは必須項目です',
     'errShouldBeInteger' => '0以上の整数を入力してください',
     'errShouldBeZeroOrMore' => '0以上である必要があります',
     'errSingleQuotation' => '配列要素をシングルクォーテーションで囲んでください。',
+
     'msgDeleteConfirm' => '本当に削除してよいですか？',
     'msgMasterDbConnectionError' => 'マスターDBに接続できません',
     'msgPgpoolConfNotFound' => 'pgpool.confが見つかりません',
     'msgPleaseSetup' => '設定ファイルが見つかりません。セットアップを実行してください。',
-	'msgReloadPgpool' => '設定ファイルを再読み込みしてもよろしいですか？',
+    'msgReloadPgpool' => '設定ファイルを再読み込みしてもよろしいですか？',
     'msgRestart' => '変更を反映するには再起動してください',
     'msgRestartPgpool' => 'pgpoolを再起動してよろしいですか？',
     'msgSameAsPasswordFile' => '値はパスワードファイルの設定値となります',
@@ -115,9 +172,15 @@ $message = array(
     'msgStopPgpool' => 'pgpoolを停止してよいですか？',
     'msgUpdateComplete' => '更新は正常に終了しました',
     'msgUpdateFailed' => '更新に失敗しました',
+    'msgDetachConfirm' => 'このノードを切断してよいですか？',
+    'msgReturnConfirm' => 'このノードを復帰させてよいですか？',
+    'msgRecoveryConfirm' => 'このノードをリカバリしますか？',
+    'msgRPromoteConfirm' => 'このノードをマスタに昇格しますか？',
+
     'strAdd' => '追加',
     'strAdminPassword' => '管理者パスワード',
     'strBack' => '戻る',
+    'strBackendPid' => 'バックエンドプロセスID',
     'strCancel' => 'キャンセル',
     'strChangePassword' => 'パスワード変更',
     'strClear' => 'クリア',
@@ -125,6 +188,8 @@ $message = array(
     'strCmdC' => 'クエリキャッシュクリア',
     'strCmdD' => 'デバッグモード',
     'strCmdDesc' => '空白の場合には無視',
+    'strCmdLargeC' => 'オンメモリキャッシュの oid map をリセット',
+    'strCmdLargeD' => 'pgpool_status を無視',
     'strCmdM' => '停止モード',
     'strCmdN' => '非デーモンモード',
     'strCmdPcpFile' => 'pcp.conf',
@@ -154,6 +219,7 @@ $message = array(
     'strErrorMessage' => 'エラーメッセージ',
     'strExecute' => '実行',
     'strFeature' => '機能',
+    'strFrontendConnected' => 'フロントエンド接続有無',
     'strHealthCheck' => 'ヘルスチェック',
     'strHelp' => 'ヘルプ',
     'strInvalidation' => '無効',
@@ -165,11 +231,12 @@ $message = array(
     'strLoginName' => 'ログイン名',
     'strLogout' => 'ログアウト',
     'strMasterServer' => 'マスターサーバ',
+    'strMasterSlaveMode' => 'マスタースレーブモード',
     'strMeasures' => '対策',
     'strNodeInfo' => 'ノード情報',
     'strNodeStatus' => 'ノードステータス',
-    'strNodeStatus1' => 'ノード稼働中。接続無し',
-    'strNodeStatus2' => 'ノード稼働中。接続有り',
+    'strNodeStatus1' => 'ノード稼働中。接続無し。',
+    'strNodeStatus2' => 'ノード稼働中。接続有り。',
     'strNodeStatus3' => 'ノードダウン',
     'strNoNode' => 'ノードがありません',
     'strOff' => 'オフ',
@@ -194,13 +261,15 @@ $message = array(
     'strPgpoolLogFile' => 'pgpoolログ出力先',
     'strPgpoolManagementSystem' => 'pgpool-II管理システム',
     'strPgpoolServer' => 'pgpool-IIサーバ',
-    'strPgpoolStatus' => 'pgpoolステータス',    
+    'strPgpoolStatus' => 'pgpoolステータス',
     'strPgpoolSummary' => 'サマリー',
     'strPleaseWait' => 'しばらくお待ちください・・・',
     'strPort' => 'ポート',
+    'strPrimaryRunning' => 'プライマリとして稼働中',
     'strProcId' => 'プロセスID',
     'strProcInfo' => 'プロセス情報',
     'strProcTime' => 'プロセススタート時刻',
+    'strPromote' => 'マスタ昇格',
     'strProtocolMajorVersion' => 'プロトコルメジャーバージョン',
     'strProtocolNinorVersion' => 'プロトコルマイナーバージョン',
     'strQueryCache' => 'クエリキャッシュ',
@@ -218,11 +287,14 @@ $message = array(
     'strSecondaryServer' => 'セカンダリサーバ',
     'strSetting' => '管理ツール設定',
     'strSetup' => 'セットアップ',
+    'strSlonyMode' => 'Slony-Iモード',
+    'strStandbyRunning' => 'スタンバイとして稼働中',
     'strStartOption' => '起動オプション',
     'strStartPgpool' => 'pgpool起動',
     'strStatus' => 'ステータス',
     'strStopOption' => 'pgpool停止オプション',
     'strStopPgpool' => 'pgpool停止',
+    'strStreamingRepMode' => 'Streaming Replicationモード',
     'strSummary' => '概要',
     'strSystemDb' => '分散ルール',
     'strTable' => 'テーブル名',
@@ -230,7 +302,9 @@ $message = array(
     'strUp' => 'アップ',
     'strUpdate' => '更新',
     'strValue' => '値',
+    'strVersion' => 'pgpool-II バージョン',
     'strWeight' => 'ウェイト',
+
     'e1' => 'pgmgt.conf.phpが見つかりません',
     'e2' => 'メッセージカタログが見つかりません',
     'e3' => 'pcpコマンドエラーが発生しました',
@@ -275,7 +349,8 @@ $message = array(
     'e6003' => 'pcp.confに書き込みができません',
     'e7001' => 'pcp.confが見つかりません',
     'e8001' => '詳細情報が取得できません',
-    'cautionaryNote' => '注: 更新した設定を反映させるには、設定のリロードが必要です。また、[*]が付いている項目は pgpool の再起動が必要となります。',
+    'cautionaryNote' => '注: 更新した設定を反映させるには、設定のリロードが必要です。'.
+                        'また、[*]が付いている項目は pgpool の再起動が必要となります。',
 
 );
 
